==> libebml_0.6.3.orig.tar.gz: libebml-0.6.3/src/platform/win32/WinIOCallback.h <==
/****************************************************************************
** libebml : parse EBML files, see http://embl.sourceforge.net/
**
** <file/class description>
**
** Copyright (C) 2002-2003 Steve Lhomme.  All rights reserved.
**
** This file may be distributed under the terms of the Q Public License
** as defined by Trolltech AS of Norway and appearing in the file
** LICENSE.QPL included in the packaging of this file.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
** Licensees holding an other license may use this file in accordance with 
** the Agreement provided with the Software.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
** See http://www.matroska.org/license/qpl/ for QPL licensing information.
** See http://www.matroska.org/license/gpl/ for GPL licensing information.
**
** Contact license@matroska.org if any conditions of this licensing are
** not clear to you.
**
**********************************************************************/
/*!
	\file
	\version \$Id: WinIOCallback.h,v 1.4 2003/09/15 02:31:10 jcsston Exp $
	\author Steve Lhomme     <robux4 @ users.sf.net>
	\author Jory Stone       <jcsston @ toughguy.net>
	\author Cyrius           <suiryc @ users.sf.net>
*/

#ifndef LIBEBML_WINIOCALLBACK_H
#define LIBEBML_WINIOCALLBACK_H

#include <windows.h>
#include <stdexcept>
#include <string>
#include "ebml/IOCallback.h"

START_LIBEBML_NAMESPACE

class WinIOCallback: public IOCallback
{	
public:
	WinIOCallback(const wchar_t* Path, const open_mode aMode, DWORD dwFlags=0);
	WinIOCallback(const char* Path, const open_mode aMode, DWORD dwFlags=0);
	virtual ~WinIOCallback();

	bool open(const wchar_t* Path, const open_mode Mode, DWORD dwFlags=0);
	bool open(const char* Path, const open_mode Mode, DWORD dwFlags=0);

	virtual uint32 read(void*Buffer,size_t Size);
	virtual size_t write(const void*Buffer,size_t Size);
	virtual void setFilePointer(int64 Offset,seek_mode Mode=seek_beginning);
	virtual uint64 getFilePointer();
	virtual void close();
	
	bool IsOk() { return mOk; };
	std::string &GetLastErrorStr() { return mLastErrorStr; };
private:
	HANDLE mFile;
	bool mOk;
	std::string mLastErrorStr;
};

END_LIBEBML_NAMESPACE

#endif // LIBEBML_WINIOCALLBACK_H

==> libebml-0.7.0.tar.gz: libebml-0.7.0/src/platform/win32/WinIOCallback.h <==
/****************************************************************************
** libebml : parse EBML files, see http://embl.sourceforge.net/
**
** <file/class description>
**
** Copyright (C) 2002-2003 Steve Lhomme.  All rights reserved.
**
** This library is free software; you can redistribute it and/or
** modify it under the terms of the GNU Lesser General Public
** License as published by the Free Software Foundation; either
** version 2.1 of the License, or (at your option) any later version.
** 
** This library is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
** Lesser General Public License for more details.
** 
** You should have received a copy of the GNU Lesser General Public
** License along with this library; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**
** See http://www.matroska.org/license/lgpl/ for LGPL licensing information.
**
** Contact license@matroska.org if any conditions of this licensing are
** not clear to you.
**
**********************************************************************/
/*!
	\file
	\version \$Id: WinIOCallback.h,v 1.6 2004/04/14 23:17:53 robux4 Exp $
	\author Steve Lhomme     <robux4 @ users.sf.net>
	\author Jory Stone       <jcsston @ toughguy.net>
	\author Cyrius           <suiryc @ users.sf.net>
*/

#ifndef LIBEBML_WINIOCALLBACK_H
#define LIBEBML_WINIOCALLBACK_H

#include <windows.h>
#include <stdexcept>
#include <string>
#include "ebml/IOCallback.h"

START_LIBEBML_NAMESPACE

class WinIOCallback: public IOCallback
{	
public:
	WinIOCallback(const wchar_t* Path, const open_mode aMode, DWORD dwFlags=0);
	WinIOCallback(const char* Path, const open_mode aMode, DWORD dwFlags=0);
	virtual ~WinIOCallback();

	bool open(const wchar_t* Path, const open_mode Mode, DWORD dwFlags=0);
	bool open(const char* Path, const open_mode Mode, DWORD dwFlags=0);

	virtual uint32 read(void*Buffer,size_t Size);
	virtual size_t write(const void*Buffer,size_t Size);
	virtual void setFilePointer(int64 Offset,seek_mode Mode=seek_beginning);
	virtual uint64 getFilePointer();
	virtual void close();
	
	bool IsOk() { return mOk; };	
	const std::string &GetLastErrorStr() { return mLastErrorStr; };
	bool SetEOF();
protected:
	bool mOk;
	std::string mLastErrorStr;

	HANDLE mFile;
};

END_LIBEBML_NAMESPACE

#endif // LIBEBML_WINIOCALLBACK_H
